const { main:Main } = imports.ui;
const { St, Clutter, Pango } = imports.gi;

const ExtensionUtils = imports.misc.extensionUtils;
const Self = ExtensionUtils.getCurrentExtension();


class Extension {
    constructor() { }

    // Nothing we do on enable() method. it started on disable() method
    enable() { }

    // Extension starts here
    disable() {
        // Initialize schema
        this.settings = ExtensionUtils.getSettings(
            `org.gnome.shell.extensions.${Self.metadata.id}`
        );
        // Run only when current session mode is in "unlock-dialog"
        if (Main.sessionMode.currentMode == 'unlock-dialog') {
            // Clock stack from screenShield
            let clockStack = Main.screenShield._dialog._clock;

            // Message Label
            this._message = new St.Label({
                text: this.settings.get_string('message'),
                x_align: Clutter.ActorAlign.CENTER,
                opacity: 255 * 0.6, // A bit low of opacity
                width: 320 // Recommended size
            });
            // Set clutter text from this._message
            this._message.clutter_text.set({
                line_alignment: Pango.Alignment.CENTER,
                line_wrap: true,
                line_wrap_mode: Pango.WrapMode.WORD,
            });
            // Append above date label from clockStack
            clockStack.insert_child_above(this._message, clockStack._date);

            // Remove used padding top of lock hint with message height
            clockStack._hint.set({
                style: `padding-top: ${(this._message.height >= 48 ? 0 : 48 - this._message.height)}px;`,
            });
        }
        // When user unlocks the screen, the message will automatically destroy by unlockDialog
    }
}

function init() { return new Extension(); }
