'use strict';

const Gio = imports.gi.Gio;
const Gtk = imports.gi.Gtk;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();


function init() { }

function buildPrefsWidget() {
    this.settings = ExtensionUtils.getSettings(`org.gnome.shell.extensions.${Me.metadata.id}`);

    // Create a parent widget that we'll return from this function
    let prefsWidget = new Gtk.Box({
        margin_start: 24,
        margin_end: 24,
        margin_top: 24,
        margin_bottom: 24,
        spacing: 24,
        orientation: Gtk.Orientation.VERTICAL,
        hexpand: true,
        valign: Gtk.Align.CENTER,
        visible: true
    });

    // Title
    let title = new Gtk.Label({
        label: `<span size="16384"><b>${Me.metadata.name} Preferences</b></span>`,
        halign: Gtk.Align.FILL,
        justify: Gtk.Justification.CENTER,
        use_markup: true,
        wrap: true,
        visible: true
    });
    prefsWidget.append(title);
    
    // About Extension
    let infoLabel = new Gtk.Label({
        label: "<b>This extension let's you add your message to the lock screen (unlockDialog)</b>",
        halign: Gtk.Align.FILL,
        justify: Gtk.Justification.CENTER,
        use_markup: true,
        wrap: true,
        visible: true
    });
    prefsWidget.append(infoLabel);

    // Message
    let messageWidget = new Gtk.Box({
        spacing: 8,
        orientation: Gtk.Orientation.VERTICAL,
        hexpand: true,
        visible: true
    });
    prefsWidget.append(messageWidget);
    let messageLabel = new Gtk.Label({
        label: 'Message:',
        halign: Gtk.Align.START,
        visible: true
    });
    messageWidget.append(messageLabel);
    let messageEntry = new Gtk.Entry({
        text: this.settings.get_string('message'),
        max_length: 64,
        hexpand: true,
        visible: true
    });
    messageWidget.append(messageEntry);

    // About Extension
    let aboutLabel = new Gtk.Label({
        label: 
            `${Me.metadata.name}. Version ${Me.metadata.version}\n` +
            `Maintained by: AdvendraDeswanta`,
        halign: Gtk.Align.CENTER,
        justify: Gtk.Justification.CENTER,
        visible: true
    });
    prefsWidget.append(aboutLabel);

    // Bind the messageWidget to the `message` key
    this.settings.bind(
        'message',
        messageEntry,
        'text',
        Gio.SettingsBindFlags.DEFAULT
    );

    // Adaptive content
    prefsWidget.connect('realize', () => {
        let root = prefsWidget.get_root();
        let margin = 0.2;
        prefsWidget.set({
            margin_start: root.default_width * margin,
            margin_end: root.default_width * margin,
        });
        root.connect('notify::default-width', () => {
            prefsWidget.set({
                margin_start: root.default_width * margin,
                margin_end: root.default_width * margin,
            })
            root.measure(Gtk.Orientation.HORIZONTAL, -1)
        });
    });

    // Return the widget which will be added to the window
    return prefsWidget;
}
